=============
Api Reference
=============

A ``client.Client`` instance has the following submodules (each one
corresponding to an API endpoint):

.. toctree::
   :maxdepth: 2

   report
   info
   rating
   collector
   storage
